@@ -24,6 +24,9 @@
 
 #include <QtCore/QByteArray> //qstrdup
 #include <QtCore/QFile> //decodeName()
+#include <QtCore/QDebug>
+#include <kglobal.h>
+#include <klocale.h>
 
 #include <stdlib.h>
 
@@ -224,17 +227,13 @@ class File
 public:
     friend class Folder;
 
-    enum UnitPrefix { kilo, mega, giga, tera };
-
-    static const uint DENOMINATOR[4];
-
 public:
     File(const char *name, FileSize size) : m_parent(0), m_name(qstrdup(name)), m_size(size) {}
     virtual ~File() {
         delete [] m_name;
     }
 
-    const Folder *parent() const {
+    Folder *parent() const {
         return m_parent;
     }
     const char *name8Bit() const {
@@ -252,10 +251,9 @@ public:
     }
 
     QString fullPath(const Folder* = 0) const;
-    QString humanReadableSize(UnitPrefix key = mega) const;
-
-public:
-    static QString humanReadableSize(FileSize size, UnitPrefix Key = mega);
+    QString humanReadableSize() const {
+        return KGlobal::locale()->formatByteSize(m_size);
+    }
 
 protected:
     File(const char *name, FileSize size, Folder *parent) : m_parent(parent), m_name(qstrdup(name)), m_size(size) {}
@@ -300,6 +298,16 @@ public:
     {
         append(new File(name, size, this));
     }
+    
+    /// removes a file
+    void remove(const File *f) {
+        for (Iterator<File> it = iterator(); it != end(); ++it)
+            if (f == (*it))
+                it.remove();
+        
+        for (Folder *d = this; d; d = d->parent())
+            d->m_size -= f->size();
+    }
 
 private:
     void append(File *p)
